package
Version:
v1.0.4
Opens a new window with list of versions in this module.
Published: Mar 22, 2020
License: MIT
Opens a new window with license information.
Imports: 12
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
Server struct {
Port int `json:"port"`
Timeout time.Duration `json:"timeout"`
} `json:"server"`
Log struct {
FilePath string `json:"file_path"`
} `json:"log"`
Model struct {
FilePath string `json:"file_path"`
BinaryFilePath string `json:"binary_file_path"`
} `json:"model"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.